@@ -1,7 +1,7 @@
 /* LICENSE BEGIN
     This file is part of the SixtyFPS Project -- https://sixtyfps.io
-    Copyright (c) 2020 Olivier Goffart <olivier.goffart@sixtyfps.io>
-    Copyright (c) 2020 Simon Hausmann <simon.hausmann@sixtyfps.io>
+    Copyright (c) 2021 Olivier Goffart <olivier.goffart@sixtyfps.io>
+    Copyright (c) 2021 Simon Hausmann <simon.hausmann@sixtyfps.io>
 
     SPDX-License-Identifier: GPL-3.0-only
     This file is also available under commercial licensing terms.
@@ -66,7 +66,7 @@ fn callback_simple_test() {
     let weak = Rc::downgrade(&c);
     c.clicked.set_handler(move |()| weak.upgrade().unwrap().pressed.set(true));
     c.clicked.call(&());
-    assert_eq!(c.pressed.get(), true);
+    assert!(c.pressed.get());
 }
 
 #[cfg(feature = "ffi")]
