@@ -1,7 +1,7 @@
 /* LICENSE BEGIN
     This file is part of the SixtyFPS Project -- https://sixtyfps.io
-    Copyright (c) 2020 Olivier Goffart <olivier.goffart@sixtyfps.io>
-    Copyright (c) 2020 Simon Hausmann <simon.hausmann@sixtyfps.io>
+    Copyright (c) 2021 Olivier Goffart <olivier.goffart@sixtyfps.io>
+    Copyright (c) 2021 Simon Hausmann <simon.hausmann@sixtyfps.io>
 
     SPDX-License-Identifier: GPL-3.0-only
     This file is also available under commercial licensing terms.
@@ -11,10 +11,13 @@ LICENSE END */
 
 # SixtyFPS runtime library
 
-*NOTE*: This library is an internal crate for the [SixtyFPS project](https://sixtyfps.io).
-This crate should not be used directly by application using SixtyFPS.
+**NOTE**: This library is an **internal** crate for the [SixtyFPS project](https://sixtyfps.io).
+This crate should **not be used directly** by applications using SixtyFPS.
 You should use the `sixtyfps` crate instead.
 
+**WARNING**: This crate does not follow the semver convention for versioning and can
+only be used with `version = "=x.y.z"` in Cargo.toml.
+
 */
 #![doc(html_logo_url = "https://sixtyfps.io/resources/logo.drawio.svg")]
 #![deny(unsafe_code)]
@@ -86,7 +89,7 @@ pub fn use_modules() -> usize {
             + graphics::ffi::sixtyfps_new_path_elements as usize
             + properties::ffi::sixtyfps_property_init as usize
             + string::ffi::sixtyfps_shared_string_bytes as usize
-            + window::ffi::sixtyfps_component_window_drop as usize
+            + window::ffi::sixtyfps_windowrc_drop as usize
             + component::ffi::sixtyfps_component_init_items as usize
             + timers::ffi::sixtyfps_timer_start as usize
             + graphics::color::ffi::sixtyfps_color_brighter as usize
