@@ -675,6 +675,12 @@ impl<T: Clone> Property<T> {
     pub fn is_dirty(&self) -> bool {
         self.handle.access(|binding| binding.map_or(false, |b| b.dirty.get()))
     }
+
+    /// Internal function to mark the property as dirty and notify dependencies, regardless of
+    /// whether the property value has actually changed or not.
+    pub fn mark_dirty(&self) {
+        self.handle.mark_dirty()
+    }
 }
 
 impl<T: Clone + InterpolatedPropertyValue + 'static> Property<T> {
@@ -705,6 +711,7 @@ impl<T: Clone + InterpolatedPropertyValue + 'static> Property<T> {
                 }
             });
         }
+        self.handle.mark_dirty();
     }
 
     /// Set a binding to this property.
@@ -1808,6 +1815,12 @@ pub(crate) mod ffi {
         handle.0.access(|binding| binding.map_or(false, |b| b.dirty.get()))
     }
 
+    /// Marks the property as dirty and notifies dependencies.
+    #[no_mangle]
+    pub extern "C" fn sixtyfps_property_mark_dirty(handle: &PropertyHandleOpaque) {
+        handle.0.mark_dirty()
+    }
+
     /// Destroy handle
     #[no_mangle]
     pub unsafe extern "C" fn sixtyfps_property_drop(handle: *mut PropertyHandleOpaque) {
@@ -1835,6 +1848,7 @@ pub(crate) mod ffi {
                 }
             })
         };
+        handle.0.mark_dirty();
     }
 
     /// Internal function to set up a property animation to the specified target value for an integer property.
