@@ -15,7 +15,6 @@ use crate::graphics::{Point, Size};
 use crate::input::{KeyEvent, MouseEvent, MouseInputState, TextCursorBlinker};
 use crate::items::{ItemRc, ItemRef, ItemWeak};
 use crate::properties::{Property, PropertyTracker};
-use crate::slice::Slice;
 use core::cell::Cell;
 use core::pin::Pin;
 use std::cell::RefCell;
@@ -35,7 +34,7 @@ pub trait PlatformWindow {
 
     /// This function is called by the generated code when a component and therefore its tree of items are destroyed. The
     /// implementation typically uses this to free the underlying graphics resources cached via [`crate::graphics::RenderingCache`].
-    fn free_graphics_resources<'a>(&self, items: &Slice<'a, Pin<ItemRef<'a>>>);
+    fn free_graphics_resources<'a>(&self, items: &mut dyn Iterator<Item = Pin<ItemRef<'a>>>);
 
     /// Show a popup at the given position
     fn show_popup(&self, popup: &ComponentRc, position: Point);
@@ -472,6 +471,19 @@ impl Window {
         size
     }
 
+    /// Show a popup at the given position relative to the item
+    pub fn show_popup(&self, popup: &ComponentRc, mut position: Point, parent_item: &ItemRc) {
+        let mut parent_item = parent_item.clone();
+        loop {
+            position += parent_item.borrow().as_ref().geometry().origin.to_vector();
+            parent_item = match parent_item.parent_item().upgrade() {
+                None => break,
+                Some(pi) => pi,
+            }
+        }
+        self.platform_window.get().unwrap().show_popup(popup, position)
+    }
+
     /// Removes any active popup.
     pub fn close_popup(&self) {
         if let Some(current_popup) = self.active_popup.replace(None) {
@@ -513,6 +525,21 @@ impl Window {
             })
             .unwrap_or_default()
     }
+
+    /// Sets the size of the window item. This method is typically called in response to receiving a
+    /// window resize event from the windowing system.
+    /// Size is in logical pixels.
+    pub fn set_window_item_geometry(&self, width: f32, height: f32) {
+        if let Some(component_rc) = self.try_component() {
+            let component = ComponentRc::borrow_pin(&component_rc);
+            let root_item = component.as_ref().get_item_ref(0);
+            if let Some(window_item) = ItemRef::downcast_pin::<crate::items::WindowItem>(root_item)
+            {
+                window_item.width.set(width);
+                window_item.height.set(height);
+            }
+        }
+    }
 }
 
 impl core::ops::Deref for Window {
@@ -575,6 +602,7 @@ pub mod ffi {
     #![allow(unsafe_code)]
 
     use super::*;
+    use crate::slice::Slice;
 
     #[allow(non_camel_case_types)]
     type c_void = ();
@@ -642,7 +670,7 @@ pub mod ffi {
         items: &Slice<'a, Pin<ItemRef<'a>>>,
     ) {
         let window = &*(handle as *const WindowRc);
-        window.free_graphics_resources(items)
+        window.free_graphics_resources(&mut items.iter().cloned())
     }
 
     /// Sets the focus item.
@@ -671,9 +699,10 @@ pub mod ffi {
         handle: *const WindowRcOpaque,
         popup: &ComponentRc,
         position: crate::graphics::Point,
+        parent_item: &ItemRc,
     ) {
         let window = &*(handle as *const WindowRc);
-        window.show_popup(popup, position);
+        window.show_popup(popup, position, parent_item);
     }
     /// Close the current popup
     pub unsafe extern "C" fn sixtyfps_windowrc_close_popup(handle: *const WindowRcOpaque) {
